#include <cassert>
#include <iostream>
#include <vector>
#include <random>
#include <set>
#include <algorithm>
#include <string>
#include <map>
#include <sstream>
#include <regex>
#include <deque>
#include <numeric>
#include <fstream>
#include <queue>
#include <unordered_map>

constexpr int64_t p = 998244353;

int64_t modpow(int64_t x, int64_t n)
{
    int64_t result = 1;
    while (n > 0)
    {
        if (n % 2)
            result = (result * x) % p;
        x = (x * x) % p;
        n /= 2;
    }
    return result;
}

int64_t modinv(int64_t x)
{
    return modpow(x, p - 2);
}

int main()
{    
    int n;
    std::cin >> n;
    std::vector<int> parent(n);
    std::vector<std::vector<int> > children(n);
    for (int i = 0; i < n-1; i++)
    {
        int a, b;
        std::cin >> a >> b;
        parent[b - 1] = a - 1;
        children[a - 1].push_back(b - 1);
    }

    parent[0] = -1;

    std::vector<int64_t> withred(n);
    std::vector<int64_t> withoutred(n);

    std::vector<int> valences(n);
    std::deque<int> toprocess;
    for (int i = 0; i < n; i++)
    {
        valences[i] = children[i].size();
        if (valences[i] == 0)
            toprocess.push_back(i);
    }

    while (!toprocess.empty())
    {
        int next = toprocess.front();
        toprocess.pop_front();

        int nchildren = children[next].size();

        std::vector<int64_t> prefixproducts(nchildren + 1);
        prefixproducts[0] = 1;
        for (int i = 0; i < nchildren; i++)
        {
            prefixproducts[i + 1] = (prefixproducts[i] * (withoutred[children[next][i]] + withred[children[next][i]])) % p;
        }
        withoutred[next] = prefixproducts[nchildren];
        std::vector<int64_t> suffixproducts(nchildren + 1);
        suffixproducts[nchildren] = 1;
        for (int i = nchildren - 1; i >= 0; i--)
        {
            suffixproducts[i] = (suffixproducts[i + 1] * (withoutred[children[next][i]] + withred[children[next][i]])) % p;
        }

        if (nchildren == 0)
        {
            withred[next] = 1;
        }
        else
        {
            int64_t red = 0;
            for (int i = 0; i < nchildren; i++)
            {
                int64_t term = (prefixproducts[i] * withred[children[next][i]]) % p;
                term = (term * suffixproducts[i + 1]) % p;
                red = (red + term) % p;
            }
            withred[next] = red;
        }

        int p = parent[next];
        if (p != -1)
        {
            valences[p]--;
            if (valences[p] == 0)
                toprocess.push_back(p);
        }
    }

    std::cout << withoutred[0] << std::endl;
}
