#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include <math.h>

typedef unsigned long DWORD;
typedef unsigned short WORD;
typedef unsigned char BYTE;
typedef unsigned long long DDWORD;

#undef DEBUG
#define MAX_N	500000
#define MIN_N	3
DDWORD MODULUS = (998244353);

typedef struct _node_ {
	struct _node_ *pparent;
	struct _node_ *plchild;
	struct _node_ *prsib;
	DDWORD con_cnt;
	DDWORD dis_cnt;
	int nchildren;
	int seenchildren;
	int index;
} TNODE, *PTNODE;

int n_nodes, nxtInd, scanInd;

TNODE nodes[MAX_N+1];
PTNODE workNodes[MAX_N];

void InitNodes()
{
	int i;
	PTNODE p;
	for(i = 0, p = &(nodes[1]); i < n_nodes; i++, p++) {
		p->plchild = p->pparent = p->prsib = NULL;
		p->con_cnt = p->dis_cnt = 0;
		p->nchildren = p->seenchildren = 0;
		p->index = i+1;
	}
}

int AddLink(int par, int child, int linkno)
{
	PTNODE pp, pc;
	pp = &(nodes[par]);
	pc = &(nodes[child]);
	if(pc->pparent != NULL) {
		fprintf(stderr, "two parents for child %d link %d\n", child, linkno);
		return -1;
	}
	pc->pparent = pp;
	pc->prsib = pp->plchild;
	pp->plchild = pc;
	pp->nchildren++;
	return 0;
}

int FindCounts(PTNODE pp)
{
	PTNODE pt, pt2;
	DDWORD t1, t2, sum, prod;
	if(pp->nchildren == 0) {
		pp->con_cnt = 1;
		pp->dis_cnt = 1;
	} else if(pp->nchildren == 1) {
		pt = pp->plchild;
		pp->con_cnt = (pt->con_cnt + pt->dis_cnt) % MODULUS;
		pp->dis_cnt = pt->dis_cnt;
	} else if(pp->nchildren == 2) {
		pt = pp->plchild;
		pt2 = pt->prsib;
		t1 = (pt->con_cnt + pt->dis_cnt) % MODULUS;
		t2 = (pt2->con_cnt + pt2->dis_cnt) % MODULUS;
		pp->con_cnt = (t1 *t2)% MODULUS;
		t1 = (t1 * pt2->dis_cnt) % MODULUS;
		t2 = (t2 * pt->dis_cnt) % MODULUS;
		pp->dis_cnt = (t1 + t2) % MODULUS;
	} else {
		pt = pp->plchild;
		sum = 0; prod= 1;
		while( pt != NULL) {
			t1 = (pt->con_cnt + pt->dis_cnt) % MODULUS;
			sum = (sum *t1 )% MODULUS;
			t2 = (prod *pt->dis_cnt) % MODULUS;
			sum = (sum + t2) % MODULUS;
			prod = (prod *t1) % MODULUS;
			pt = pt->prsib;
		}
		pp->con_cnt = prod;
		pp->dis_cnt = sum;
	}
	return 0;
}

int FindLeaves()
{
	int i, nleaves;
	PTNODE p;
	nleaves = 0;
	nxtInd = scanInd = 0;
	for(i = 1, p = &(nodes[1]); i <= n_nodes ; i++, p++) {
		if(p->nchildren == 0) {
			nleaves++;
			p->con_cnt = 1;
			p->dis_cnt = 1;
			workNodes[nxtInd++] = p;
		}
	}
	return nleaves;
}

int ProcessNodes()
{
	PTNODE pc, pp;
	while(scanInd < (n_nodes - 1)) {
		pc = workNodes[scanInd];
		pp = pc->pparent;
		pp->seenchildren++;
		if(pp->seenchildren == pp->nchildren) {
			FindCounts(pp);
#ifdef DEBUG
			printf("%d: %llu %llu\n", pp->index, pp->con_cnt, pp->dis_cnt);
#endif
			workNodes[nxtInd++] = pp;
		}
		scanInd++;
		if(scanInd >= nxtInd) {
			fprintf(stderr, "scan %d cusught next %d\n", scanInd, nxtInd);
			return -1;
		}
	}
	return 0;
}

char inbuf[2048];
int main()
{
	int a, b, i;
	if(fgets(&(inbuf[0]), 2048, stdin) == NULL) {
		fprintf(stderr, "read failed on n nodes\n");
		return -1;
	}
	if(sscanf(&(inbuf[0]), "%d", &n_nodes) != 1) {
		fprintf(stderr, "scan failed on n nodes\n");
		return -2;
	}
	InitNodes();
	for(i = 1; i < n_nodes ; i++) {
		if(fgets(&(inbuf[0]), 2048, stdin) == NULL) {
			fprintf(stderr, "read failed on link %d\n", i);
			return -3;
		}
		if(sscanf(&(inbuf[0]), "%d %d", &a, &b) != 2) {
			fprintf(stderr, "scan failed on link %d\n", i);
			return -4;
		}
		if((a < 1) || (a > n_nodes) || (b < 1) || (b > n_nodes)) {
			fprintf(stderr, "a %d and/or b %d not in range 1...%d link %d\n", 
				a, b, n_nodes, i);
			return -5;
		}
		if(AddLink(a, b, i) != 0) {
			return -6;
		}
	}
	if(FindLeaves() == 0) {
		fprintf(stderr, "No leaf nodes\n");
		return -7;
	}
	if(ProcessNodes() != 0) {
		return -8;
	}
	printf("%llu\n", nodes[1].con_cnt);
	return 0;
}

